import os
import subprocess


def text_to_speech(text, file_name="response.wav", model="./piper/chat/zh_CN-huayan-medium.onnx"):
    """
    使用 Piper 将文本转换为语音并保存为音频文件。

    参数:
    - text (str): 要转换的文本。
    - file_name (str): 输出的音频文件名（默认是 "response.wav"）。
    - model (str): Piper 模型文件（默认是 "en_US-lessac-medium.onnx"）。
    """
    # 检查 Piper 可执行文件是否存在
    piper_path = "./piper/piper"  # Piper 可执行文件路径
    if not os.path.exists(piper_path):
        raise FileNotFoundError("Piper 可执行文件未找到，请确保路径正确并已安装 Piper。")

    # 检查模型文件是否存在
    if not os.path.exists(model):
        raise FileNotFoundError(f"模型文件 '{model}' 未找到，请确保路径正确。")

    # 构造 Piper 命令
    try:
        command = [
            piper_path,
            "--model", model,
            "--output_file", file_name
        ]

        # 通过管道向 Piper 传递文本
        process = subprocess.Popen(command, stdin=subprocess.PIPE, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
        stdout, stderr = process.communicate(input=text.encode('utf-8'))

        # 检查是否执行成功
        if process.returncode != 0:
            raise RuntimeError(f"Piper 执行失败: {stderr.decode('utf-8')}")

        print(f"语音合成完成，音频已保存到 '{file_name}'")
    except Exception as e:
        print(f"语音合成出错: {e}")


# 示例用法
if __name__ == "__main__":
    text = "你好世界"
    output_file = "response.wav"
    model_file = "./piper/chat/zh_CN-huayan-medium.onnx"  # 替换为你的模型路径
    text_to_speech(text, file_name=output_file, model=model_file)
