import time
from VoiceRecord import record_audio
from STT import recognize_speech_with_gradio
from PlayAudio import play_audio
from TTS import text_to_speech
from process_logic import process_user_input


def long_run_assistant():
    """
    永不退出的语音助手，等待唤醒词激活后进入对话模式。
    """
    print("语音助手已启动！随时可以说出唤醒词（例如：'你好助手'）激活。")

    # 配置唤醒词
    WAKE_WORD = "你好"
    SLEEP_WORDS = ["休息", "再见", "退出"]
    API_URL = "http://10.80.168.94:8080/api/query"

    # 无限循环，永不退出
    while True:
        try:
            # 录音并识别语音
            audio_file = "input.wav"
            print("正在监听中...")
            record_audio(audio_file, duration=5)  # 每次录音 3 秒
            user_input = recognize_speech_with_gradio(audio_file)

            if not user_input:
                continue  # 如果没有检测到语音输入，继续监听

            print(f"检测到用户输入：{user_input}")

            # 检测唤醒词
            if WAKE_WORD in user_input:
                print("唤醒成功！进入对话模式...")
                text_to_speech("你好，我在这里。", "response.wav")
                play_audio("response.wav")

                # 进入对话模式
                empty_input_count = 0  # 空输入计数器
                max_empty_inputs = 1  # 最大允许空输入次数

                while True:
                    print("对话模式中，等待用户输入...")
                    record_audio(audio_file, duration=5)
                    user_input = recognize_speech_with_gradio(audio_file)

                    if not user_input:
                        empty_input_count += 1  # 空输入计数器加一
                        print(f"未检测到有效输入，空输入计数：{empty_input_count}/{max_empty_inputs}")

                        # 检测是否达到最大空输入次数
                        if empty_input_count >= max_empty_inputs:
                            print("长时间未检测到有效输入，退出对话模式...")
                            text_to_speech("长时间未检测到您的输入，我将退出对话模式。", "response.wav")
                            play_audio("response.wav")
                            break
                        continue  # 继续等待用户输入

                    # 如果有有效输入，重置空输入计数器
                    empty_input_count = 0

                    print(f"用户输入内容：{user_input}")

                    # 检测退出对话模式的关键词
                    if any(word in user_input for word in SLEEP_WORDS):
                        print("检测到退出关键词，返回待机模式...")
                        text_to_speech("好的，我会继续待命。", "response.wav")
                        play_audio("response.wav")
                        break

                    # 处理用户输入，生成响应
                    response = process_user_input(user_input, API_URL)
                    print(f"系统响应：{response}")
                    text_to_speech(response, "response.wav")
                    play_audio("response.wav")

        except KeyboardInterrupt:
            # 捕捉手动中断（Ctrl+C），退出程序
            print("检测到手动中断，退出语音助手...")
            break
        except Exception as e:
            # 捕捉其他异常，打印错误信息但不中断程序
            print(f"发生错误：{e}")
            time.sleep(1)  # 稍作休眠，避免无限快速循环


if __name__ == "__main__":
    long_run_assistant()
